package upnp

import (
	"fmt"

	omd "git.loafle.net/overflow/model/discovery"
	omu "git.loafle.net/overflow/model/util"
	"git.loafle.net/overflow_scanner/probe/model"
	"github.com/huin/goupnp"
)

const (
	TargetRootDevice = "upnp:rootdevice"
	TargetSSDPAll    = "ssdp:all"
)

func Scan(discovered model.Discovered) {
	devs, err := goupnp.DiscoverDevices(TargetRootDevice)
	if nil != err {
		fmt.Println("DeletePortMapping: ", err)
	}

LOOP:
	for _, dev := range devs {
		rd := dev.Root.Device
		if !rd.PresentationURL.Ok {
			continue LOOP
		}

		discovered.AddHost(&omd.Host{
			MetaIPType: discovered.Zone().MetaIPType,
			Name:       rd.FriendlyName,
			Address:    rd.PresentationURL.URL.Host,
			Meta: map[string]string{
				"DeviceType":       rd.DeviceType,
				"Manufacturer":     rd.Manufacturer,
				"ManufacturerURL":  rd.ManufacturerURL.Str,
				"ModelName":        rd.ModelName,
				"ModelDescription": rd.ModelDescription,
				"ModelNumber":      rd.ModelNumber,
				"SerialNumber":     rd.SerialNumber,
				"UDN":              rd.UDN,
				"UPC":              rd.UPC,
			},
			Zone:           discovered.Zone(),
			DiscoveredDate: omu.NowPtr(),
		})
	}
}
